'----------------------------------------------------------------------
'FILE DESCRIPTION: SAMPLE.VBS is a collection of sample VrmlPad macros.
'----------------------------------------------------------------------

'------------------------------------------------------------
'Inserts all fields of the selected node with default values.
'------------------------------------------------------------

BindCommand "Complete_All", "Inserts all fields of the node","Commands|Complete All", "Alt+C"

Sub Complete_All
	Set ent = CurrentEntity
	If ent Is Nothing Then Exit Sub
	If ent.EntityType = vpNode Then
		BeginOperation "Complete All"
		For Each fld In ent.Fields
			fld.Implicit = False
		Next
		EndOperation
	End If
End Sub

'-------------------------------------------------------
'Prompts for a node name and selects the specified node.
'-------------------------------------------------------

BindCommand "Go_To_Node", "Prompts for a node name and selects the specified node", "Commands|Go To Node...", "Alt+G"
Sub Go_To_Node
	nn = InputBox("Enter a node name:","Go To Node")
	If nn = "" Then Exit Sub
	On Error Resume Next
	Set node = Nodes(nn)
	If node Is Nothing Then
		Set node = CurrentContext.Nodes(nn)
	End If
	If node Is Nothing Then
		nn = CStr(nn)
		MsgBox "Cant find node " + nn + "",0,"Go To Node"
	Else
		node.Range(vprnName).Select
	End If
End Sub

'-----------------------------------------------------------------
'Enumerates all faces in the document and in the selected faceset.
'-----------------------------------------------------------------

BindCommand "Count_Faces", "Enumerates all faces", "Commands|Count &Faces...", "Alt+F"
BindPopup "Count_Faces", "Count &Faces...", "IndexedFaceSet, IndexedFaceSet.*"

Function FacesInFaceset (fs)
	count = 0
	newface = True
	For Each ind In fs("coordIndex").Value
		If ind < 0 Then
			newface = True
		ElseIf newface Then
			count = count + 1
			newface = False
		End If
	Next
	FacesInFaceset = count
End Function

Sub Count_Faces
	count = 0
	aa = 0
	Window.StatusText "Counting faces of IndexedFaceSets", &hE07000
	For Each fs In StdProtos("IndexedFaceSet").Instances
		ref = 1 + fs.References.Count 
		count = count + (FacesInFaceset(fs) * ref)
	Next
	Window.StatusText "Counting faces of ElevationGrids", &hE07000
	For Each fs In StdProtos("ElevationGrid").Instances
		ref = 1 + fs.References.Count 
		Count = count + (( (fs("xDimension")-1)*(fs("zDimension")-1)*2 ) * ref)
	Next
	Window.StatusText "Counting faces of Boxes", &hE07000
	For Each fs In StdProtos("Box").Instances
		ref = 1 + fs.References.Count 
		Count = count + (12 * ref)
	Next
	Window.StatusText "Counting faces of Spheres", &hE07000
	For Each fs In StdProtos("Sphere").Instances
		ref = 1 + fs.References.Count
		Count = count + (240 * ref)
	Next
	Window.StatusText "Counting faces of Cylinders", &hE07000
	For Each fs In StdProtos("Cylinder").Instances
		ref = 1 + fs.References.Count 
		side = fs("side")
		top = fs("top")
		bottom = fs("bottom")
		If side Then Count = count + (32 * ref)
		If top Then Count = count + (16 * ref)
		If bottom Then Count = count + (16 * ref)
	Next
	Window.StatusText "Counting faces of Cones", &hE07000
	For Each fs In StdProtos("Cone").Instances
		ref = 1 + fs.References.Count 
		side = fs("side")
		bottom = fs("bottom")
		If side Then Count = Count + (16 * ref)
		If bottom Then Count = Count + (16 * ref)
	Next
	
	str = "Total " & count & " faces"

	Set ent = CurrentEntity
	Do Until ent Is Nothing
		If ent.EntityType = vpNode Then
			If ent.TypeName = "IndexedFaceSet" Then
				str = str & vbCrLf & FacesInFaceset(ent)
				str = str + " in the selected faceset"
				Exit Do
			End If
			If ent.TypeName = "ElevationGrid" Then
				str = str & vbCrLf & ( (ent("xDimension")-1)*(ent("zDimension")-1)*2 )
				str = str + " in the selected elevation grid"
				Exit Do
			End If
			If ent.TypeName = "Box" Then
				str = str & vbCrLf & 12 
				str = str + " in the selected Box"
				Exit Do
			End If
			If ent.TypeName = "Sphere" Then
				str = str & vbCrLf & 240 
				str = str + " in the selected Sphere"
				Exit Do
			End If
			If ent.TypeName = "Cylinder" Then
					side = ent("side")
					top = ent("top")
					bottom = ent("bottom")
					If side Then aa = aa + 32
					If top Then aa = aa + 16
					If bottom Then aa = aa + 16
				str = str & vbCrLf & aa 
				str = str + " in the selected Cylinder"
				Exit Do
			End If
			If ent.TypeName = "Cone" Then
					side = ent("side")
					bottom = ent("bottom")
					If side Then aa = aa + 16
					If bottom Then aa = aa + 16
				str = str & vbCrLf & aa 
				str = str + " in the selected Cone"
				Exit Do
			End If
		End If
		Set ent = ent.Owner
	Loop
	MsgBox "Counting: " + str,0,"Count Faces"
End Sub

'------------------------------------------------------------
'Wraps the selected node by Group, Transform or Anchor nodes.
'------------------------------------------------------------

Sub WrapNodeBy (env)
	Set node = CurrentEntity
	If node Is Nothing Then Exit Sub
	If node.EntityType <> vpNode And _
		node.EntityType <> vpNodeRef Then Exit Sub
	Set owner = node.Owner
	If owner Is Nothing Then
		Set coll = RootNodes
	ElseIf owner.EntityType = vpProto Then
		Set coll = owner.RootNodes
	ElseIf (owner.EntityType = vpField Or _
			owner.EntityType = vpFieldDecl) And _
			owner.Type = vpfMFNode Then
		Set coll = owner.Value
	Else
		MsgBox "Can't wrap this node",0,"Wrap by ..."
		Exit Sub
	End If
	BeginOperation "Wrap Node"
	Dim nn
	nn = node.name
	Set group = coll.Add(env, node.Range)("children")
	group.Add node
	node.DeleteInstance
	Set node = group(group.Count)
	If node.EntityType = vpNode Then node.name = nn
	EndOperation
End Sub

BindCommand "WrapNodeByGroup", "Wraps the selected node by Group", "Commands|&Wrap by|&Group", "Alt+5"
BindPopup "WrapNodeByGroup", "Wraps the selected node by Group", "*"

Sub WrapNodeByGroup
	WrapNodeBy("Group")
End Sub

BindCommand "WrapNodeByTransform", "Wraps the selected node by Transform", "Commands|&Wrap by|&Transform", "Alt+6"
BindPopup "WrapNodeByTransform", "Wraps node by Transform", "*"

Sub WrapNodeByTransform
	WrapNodeBy("Transform")
End Sub

BindCommand "WrapNodeByAnchor", "Wraps the selected node by Anchor", "Commands|&Wrap by|&Anchor", "Alt+7"
BindPopup "WrapNodeByAnchor", "Wraps node by Anchor", "*"

Sub WrapNodeByAnchor
	WrapNodeBy("Anchor")
End Sub

BindCommand "WrapNodeByColl", "Wraps the selected node by Collision", "Commands|&Wrap by|&Collide", "Alt+8"
BindPopup "WrapNodeByColl", "Wraps by Collision", "*"

Sub WrapNodeByColl
	WrapNodeBy("Collision")
End Sub

BindCommand "WrapNodeByBill", "Wraps the selected node by Billboard", "Commands|&Wrap by|&Billboard", "Alt+9"
BindPopup "WrapNodeByBill", "Wraps by Billboard", "*"

Sub WrapNodeByBill
	WrapNodeBy("Billboard")
End Sub

'------------------------------------------------------
'Converts Box, Cone or Cylinder node to IndexedFaceSet.
'------------------------------------------------------

BindCommand "ConvertToFaceset", "Converts Box, Cone or Cylinder to IndexedFaceSet", "Commands|To Face&set", "Alt+T"
BindPopup "ConvertToFaceset", "Convert To Face&set", "Box, Cone, Cylinder"

Sub Box2Faceset (ByVal node, ByRef coord, ByRef index)
	size = node("size")
	ReDim coord(7,2)
	For i = 0 To 7
		coord(i, 0) = (.5 - (i And 4)/4) * size.x
		coord(i, 1) = (.5 - (i And 2)/2) * size.y
		coord(i, 2) = (.5 - (i And 1)) * size.z
	Next
	index = Array(4,0,1,5,-1, 7,3,2,6,-1, 6,2,0,4,-1,_
				  2,3,1,0,-1, 3,7,5,1,-1, 7,6,4,5)
End Sub

Sub Cone2Faceset (ByVal node, ByRef coord, ByRef index)
	Const n = 20
	h = node("height")/2
	r = node("bottomRadius")
	side = node("side")
	bottom = node("bottom")
	If bottom Then k = n Else k = 0
	If side Then t = k+4*n Else t = k
	ReDim coord(n,2)
	ReDim index(t-1)
	coord(n, 1) = h
	For i = 0 To n-1
		ang = 2*3.141592*i/n
		coord(i, 0) = r * Cos(ang)
		coord(i, 2) = r * Sin(ang)
		coord(i, 1) = -h
		If bottom Then index(i) = i
		If side Then
			index(k+4*i) = -1
			index(k+4*i+1) = i
			index(k+4*i+2) = i-1
			index(k+4*i+3) = n
		End If
	Next
	If side Then index(k+2) = n-1
End Sub

Sub Cylinder2Faceset (ByVal node, ByRef coord, ByRef index)
	Const n = 20
	h = node("height")/2
	r = node("radius")
	side = node("side")
	top = node("top")
	bottom = node("bottom")
	If side Then k = 5*n Else k = 0
	If top Then m = k+n+1 Else m = k
	If bottom Then t = m+n Else t = m
	ReDim coord(2*n,2)
	ReDim index(t-1)
	For i = 0 To n-1
		ang = 2*3.141592*i/n
		coord(i, 0) = r * Cos(ang)
		coord(i, 2) = r * Sin(ang)
		coord(i, 1) = -h
		coord(i+n, 0) = coord(i, 0)
		coord(i+n, 2) = coord(i, 2)
		coord(i+n, 1) = h
		If side Then
			index(5*i) = i
			index(5*i+1) = i-1
			index(5*i+2) = n+i-1
			index(5*i+3) = n+i
			index(5*i+4) = -1
		End If
		If top Then index(k+i) = 2*n-i-1
		If bottom Then index(m+i) = i
	Next
	If side Then
		index(1) = n-1
		index(2) = 2*n-1
	End If
	If top Then index(k+n) = -1
End Sub

Sub ConvertToFaceset
	Dim coord
	Dim index
	Set node = CurrentEntity
	If Not node Is Nothing Then
		If node.EntityType = vpNode Then
			If node.TypeName = "Box" Then
				Box2Faceset node, coord, index
			ElseIf node.TypeName = "Cone" Then
				Cone2Faceset node, coord, index
			ElseIf node.TypeName = "Cylinder" Then
				Cylinder2Faceset node, coord, index
			End If
		End If
	End If
	If Not IsArray(index) Then
		MsgBox "Please, select Box, Cone or Cylinder node",0,"Convert To Faceset"
		Exit Sub
	End If
	If node.References.Count > 0 Or _
			node.InRoutes.Count  > 0 Or _
			node.OutRoutes.Count > 0 Then
		If MsgBox("All references to the node will be deleted. Continue?",_
			vbOKCancel) = vbCancel Then Exit Sub
	End If
	Set owner = node.Owner
	If Not owner Is Nothing Then
		If owner.EntityType = vpField Then
			If owner.Type = vpfSFNode Then
				BeginOperation "Convert to Faceset"
				owner.Value = "IndexedFaceSet"
				Set node = owner.Value
				node("colorPerVertex") = False
				node("creaseAngle") = 1
				node("coord") = "Coordinate"
				node("coord")("point") = coord
				node("coordIndex") = index
				EndOperation
				Exit Sub
			End If
		End If
	End If
	MsgBox "Must be in a Shape node",0,"Convert To Faceset"
End Sub

BindCommand "ScaleFacesets", "Scales all facesets in the selected PROTO or the scene" ,"Commands|Scale IndexedFaceSets...", "Alt+I"

Private Sub DoScaleNode (mx, n)
	If n Is Nothing Then Exit Sub
	If n.EntityType = vpNode Then
		Select Case n.TypeName
			Case "Shape"
				DoScaleNode mx, n("geometry").Value
			Case "IndexedFaceSet"
				DoScaleNode mx, n("coord").Value
			Case "Coordinate"
				mx.ApplyTransform n("point").Value
			Case "Viewpoint"
				n.Matrix = mx.Multiply(n.Matrix)
			Case "Transform"
				Set mx2 = n.Matrix
				mx.ApplyTransform n("translation")
				Set mx3 = n.Matrix.Divide(mx.Multiply(mx2))
				mx3.ApplyTransform n("center")
				n("center").Implicit = True
				For Each nn In n("children").Value
					DoScaleNode mx3, nn
				Next
			Case Else
				For Each f In n.Fields
					If f.Category = vpcField Or f.Category = vpcExposedField Then
						Select Case f.Type
							Case vpfSFNode
								DoScaleNode mx, f.Value
							Case vpfMFNode
								For Each nn In f.Value
									DoScaleNode mx, nn
								Next
						End Select
					End If
				Next
		End Select
	End If
End Sub

Sub ScaleFacesets
	sc = InputBox("Specify below scale factor you want the scene or the selected prototype declaration to be scaled.","Scale IndexedFaceSets", "1")
	If sc = "" Then Exit Sub
	BeginOperation "Scale Scene"
	Set mx = NewMatrix
	mx.Scale sc, sc, sc
	Set cc = CurrentContext
	If cc Is Nothing Then Set cc = Document
	For Each n In cc.RootNodes
		DoScaleNode mx, n
	Next
	EndOperation
End Sub

BindCommand "CMDsvco", "Save the file with GZip-Compression", "Commands|Document|Save compressed","Ctrl+Shift+S"

Sub CMDsvco
	Document.Save True, True
end sub

BindCommand "CMDsval", "Save all open files with GZip-Compression", "Commands|Document|Save all","Alt+Ctrl+Shift+S"

Sub CMDsval
	Window.Documents.SaveAll True
end sub

BindCommand "SPfog", "Special Nodes Fog", "Special Nodes|Fog..."
Sub SPfog
tt = InputBox("Enter fog type (LINEAR, EXPONENTIAL):","Create Fog","LINEAR")
If tt = "" Then Exit Sub
On Error Resume Next
rr = InputBox("Enter visibility range:","Create Fog","100")
cc = InputBox("Enter color (RGB):","Create Fog","1 1 1")
rr = Replace(rr, ",", ".")
cc = Replace(cc, ",", ".")
Set doc = Window.Documents.Active
doc.Selection = "Fog {" + vbCrLf
doc.Selection = " color " + cc + vbCrLf
doc.Selection = " fogType """ + tt + """" + vbCrLf
doc.Selection = " visibilityRange " + rr + vbCrLf
doc.Selection = "}" + vbCrLf
doc.Saved = False
End Sub

BindCommand "SPnav", "Special Nodes NavigationInfo", "Special Nodes|NavigationInfo..."
Sub SPnav
tt = InputBox("Enter navigation mode (ANY, WALK, EXAMINE, NONE, FLY, GAME):","Create NavigationInfo","EXAMINE")
If tt = "" Then Exit Sub
On Error Resume Next
dd = InputBox("Enter Avatar Size (collision radius, eye height, step size):","Create NavigationInfo",".25, 1.6, .75")
ss = InputBox("Enter navigation speed:","Create NavigationInfo","10")
vv = InputBox("Enter visibility limit (0 = none):","Create NavigationInfo","0")
cc = InputBox("Enter center of rotation for EXAMINE-Mode (x, y, z) leave blank if you will not specify it:","Create NavigationInfo","3, 3, 0")
zz = InputBox("Specify the near visibility (leave blank if you will not specify it):","Create NavigationInfo","1")
vv = Replace(vv, ",", ".")
ss = Replace(ss, ",", ".")
zz = Replace(zz, ",", ".")
cc = ", " + cc
zz = ", " + zz
Set doc = Window.Documents.Active
doc.Selection = "NavigationInfo {" + vbCrLf
doc.Selection = "  avatarSize	[" + dd + cc + zz + " ]" + vbCrLf
doc.Selection = "  headlight	TRUE" + vbCrLf
doc.Selection = "  speed	" + ss + vbCrLf
doc.Selection = "  type	""" + tt + """" + vbCrLf
doc.Selection = "  visibilityLimit	" + vv + vbCrLf
doc.Selection = "}" + vbCrLf
doc.Saved = False
End Sub

BindCommand "SPscript", "Special Nodes Script", "Special Nodes|Script Java EAI"
Sub SPscript
nn = InputBox("Enter DEF-Name of Scriptnode for routing:","Create Script Java EAI","jeai01")
If nn = "" Then Exit Sub
tt = InputBox("Enter URL of class-file:","Create Script Java EAI",".class")
ee = InputBox("Enter field like EventType VarType VarName:","Create Script Java EAI","eventIn SFBool check")
On Error Resume Next
Set doc = Window.Documents.Active
doc.Selection = "DEF " + nn + " Script {" + vbCrLf
doc.Selection = "	url [ """ + tt + ":"" ]" + vbCrLf
doc.Selection = "	" + ee + vbCrLf
doc.Selection = "}" + vbCrLf
doc.Saved = False
End Sub

BindCommand "SPjscript", "Special Nodes Script", "Special Nodes|Script JavaScript"
Sub SPjscript
nn = InputBox("Enter DEF-Name of Scriptnode for routing:","Create Script JavaScript","js01")
If nn = "" Then Exit Sub
ii = InputBox("Enter name of eventIn field:","Create Script JavaScript","Now")
iv = InputBox("Enter variable type of eventIn field " + ii + " (SFBool, MFString ...):","Create Script JavaScript","SFTime")
oo = InputBox("Enter name of eventOut field:","Create Script JavaScript","Do")
ov = InputBox("Enter variable type of eventOut field " + oo + " (SFBool, MFString ...):","Create Script JavaScript","SFBool")
ff = InputBox("Enter name of field:","Create Script JavaScript","Check")
fv = InputBox("Enter variable type of field  " + ff + " (SFBool, MFString ...):","Create Script JavaScript","SFFloat")
fw = InputBox("Enter default value of field  " + ff + ":","Create Script JavaScript","0")
On Error Resume Next
Set doc = Window.Documents.Active
doc.Selection = "DEF " + nn + " Script {" + vbCrLf
doc.Selection = "	eventIn " + iv + " " + ii + vbCrLf
doc.Selection = "	eventOut " + ov + " " + oo + vbCrLf
doc.Selection = "	field " + fv + " " + ff + " " + fw + vbCrLf
doc.Selection = "	url ""javascript:" + vbCrLf
doc.Selection = "	function " + ii + "(value, timestamp)" + vbCrLf
doc.Selection = "	{" + vbCrLf
doc.Selection = "	"+ oo + "=" + vbCrLf
doc.Selection = "	}" + vbCrLf
doc.Selection = "	""" + vbCrLf
doc.Selection = "}" + vbCrLf
doc.Saved = False
End Sub

BindCommand "SPview", "Special Nodes Viewpoint", "Special Nodes|Viewpoint..."
Sub SPview
pp = InputBox("Enter position:","Create Viewpoint","0 2 2")
If pp = "" Then Exit Sub
On Error Resume Next
oo = InputBox("Enter orientation:","Create Viewpoint","-1 0 0  .349066")
dd = InputBox("Enter description :","Create Viewpoint","Entry")
pp = Replace(pp, ",", ".")
oo = Replace(oo, ",", ".")
Set doc = Window.Documents.Active
doc.Selection = "Viewpoint {" + vbCrLf
doc.Selection = "	position	" + pp + vbCrLf
doc.Selection = "	orientation " + oo + vbCrLf
doc.Selection = "	fieldOfView	.785398" + vbCrLf
doc.Selection = "	jump TRUE" + vbCrLf
doc.Selection = "	description """ + dd + """" + vbCrLf
doc.Selection = "}" + vbCrLf
doc.Saved = False
End Sub

BindCommand "SPworld", "Special Nodes Worldinfo", "Special Nodes|WorldInfo..."
Sub SPworld
tt = InputBox("Enter world title:","Create WorldInfo")
If tt = "" Then Exit Sub
On Error Resume Next
ii = InputBox("Enter world author:","Create WorldInfo")
Set doc = Window.Documents.Active
doc.Selection = "WorldInfo {" + vbCrLf
doc.Selection = "  title	""" + tt + """" + vbCrLf
doc.Selection = "  info	""" + ii + """" + vbCrLf
doc.Selection = "}" + vbCrLf
doc.Saved = False
End Sub

BindCommand "BGBlk", "Background Black", "Special Nodes|Backgrounds|Black"
Sub BGBlk
Set doc = Window.Documents.Active
doc.Selection = "Background {" + vbCrLf
doc.Selection = " groundColor [ 0 0 0 ]" + vbCrLf
doc.Selection = " skyColor [ 0 0 0 ]" + vbCrLf
doc.Selection = "}" + vbCrLf
doc.Saved = False
End Sub
BindCommand "BGBlx", "Background Blaxxun", "Special Nodes|Backgrounds|Blaxxun"
Sub BGBlx
Set doc = Window.Documents.Active
doc.Selection = "Background {" + vbCrLf
doc.Selection = " skyAngle [ 1.1, 1.4, 1.57 ]" + vbCrLf
doc.Selection = " skyColor [ .224 .616 .192, .224 .616 .192, .541 .78 .431, .745 .875 .627 ]" + vbCrLf
doc.Selection = " groundAngle [ 1.4, 1.57 ]" + vbCrLf
doc.Selection = " groundColor [ .329 .357 .361, .329 .357 .361, 0 0 0 ]" + vbCrLf
doc.Selection = "}" + vbCrLf
doc.Saved = False
End Sub
BindCommand "BGBlGrd", "Background Blue Gradient", "Special Nodes|Backgrounds|Blue Gradient"
Sub BGBlGrd
Set doc = Window.Documents.Active
doc.Selection = "Background {" + vbCrLf
doc.Selection = "	skyColor [ 1 1 1, .9 .9 1, 0 .05 .1 ]" + vbCrLf
doc.Selection = "	skyAngle [ .1, 2 ]" + vbCrLf
doc.Selection = "}" + vbCrLf
doc.Saved = False
End Sub
BindCommand "BGCgr", "Background Cool Gray", "Special Nodes|Backgrounds|Cool Gray"
Sub BGCgr
Set doc = Window.Documents.Active
doc.Selection = "Background {" + vbCrLf
doc.Selection = "	skyColor [ .792 .792 .827 ]" + vbCrLf
doc.Selection = "	groundColor [ .91 .91 .945, .91 .91 .945, .851 .851 .890, .792 .792 .827 ]" + vbCrLf
doc.Selection = "	groundAngle [ 1.2, 1.5, 1.54 ]" + vbCrLf
doc.Selection = "}" + vbCrLf
doc.Saved = False
End Sub
BindCommand "BGCmo", "Background CosmoWorld", "Special Nodes|Backgrounds|CosmoWorld"
Sub BGCmo
Set doc = Window.Documents.Active
doc.Selection = "Background {" + vbCrLf
doc.Selection = " groundAngle [ 1.57079 ]" + vbCrLf
doc.Selection = " groundColor [ 1 .8 .6, .6 .4 .2 ]" + vbCrLf
doc.Selection = " skyAngle	[ .2, 1.57079 ]" + vbCrLf
doc.Selection = " skyColor	[ 1 1 0, 1 1 1, .2 .2 1 ]" + vbCrLf
doc.Selection = "}" + vbCrLf
doc.Saved = False
End Sub
BindCommand "BGbw", "Background Grayscale", "Special Nodes|Backgrounds|Grayscale"
Sub BGbw
Set doc = Window.Documents.Active
doc.Selection = "Background {" + vbCrLf
doc.Selection = " skyColor [ 0 0 0, 1.0 1.0 1.0 ]" + vbCrLf
doc.Selection = " skyAngle [ 1.6 ]" + vbCrLf
doc.Selection = " groundColor [ 1 1 1, .8 .8 .8, .2 .2 .2 ]" + vbCrLf
doc.Selection = " groundAngle [ 1.2, 1.57 ]" + vbCrLf
doc.Selection = "}" + vbCrLf
doc.Saved = False
End Sub
BindCommand "BGLnd", "Background Landmark", "Special Nodes|Backgrounds|Landmark"
Sub BGLnd
Set doc = Window.Documents.Active
doc.Selection = "Background {" + vbCrLf
doc.Selection = " skyAngle [ 1.1, 1.4, 1.57 ]" + vbCrLf
doc.Selection = " skyColor [ .176 .314 .529, .176 .314 .529, .314 .549 .784, .706 .824 .922 ]" + vbCrLf
doc.Selection = " groundAngle	[ 1.4, 1.57 ]" + vbCrLf
doc.Selection = " groundColor [ .255 .588 .275, .255 .588 .275, .216 .412 .235 ]" + vbCrLf
doc.Selection = "}" + vbCrLf
doc.Saved = False
End Sub
BindCommand "BGNat", "Background Nature", "Special Nodes|Backgrounds|Nature"
Sub BGNat
Set doc = Window.Documents.Active
doc.Selection = "Background {" + vbCrLf
doc.Selection = " groundAngle [ .9, 1.5, 1.57 ]" + vbCrLf
doc.Selection = " groundColor [ 0 .333 0, 0 .4 0, 0 .5 0, .62 .67 .60 ]" + vbCrLf
doc.Selection = " skyAngle [ .9, 1.5, 1.57 ]" + vbCrLf
doc.Selection = " skyColor [ .21 .18 .66, .2 .44 .85, .51 .81 .95, .77 .8 .82 ]" + vbCrLf
doc.Selection = "}" + vbCrLf
doc.Saved = False
End Sub
BindCommand "BGNgt", "Background Night", "Special Nodes|Backgrounds|Night"
Sub BGNgt
Set doc = Window.Documents.Active
doc.Selection = "Background {" + vbCrLf
doc.Selection = " skyColor [ 0 0 0, .118 .392 .627, 0 .2 .4 ]" + vbCrLf
doc.Selection = " skyAngle [ 1.309, 1.571 ]" + vbCrLf
doc.Selection = " groundColor [ 0 0 0, .118 .392 .627, 0 .2 .4 ]" + vbCrLf
doc.Selection = " groundAngle [ 1.309, 1.571 ]" + vbCrLf
doc.Selection = "}" + vbCrLf
doc.Saved = False
End Sub
BindCommand "BGOcn", "Background Ocean", "Special Nodes|Backgrounds|Ocean"
Sub BGOcn
Set doc = Window.Documents.Active
doc.Selection = "Background {" + vbCrLf
doc.Selection = " groundAngle [ 1.1, 1.4, 1.57 ]" + vbCrLf
doc.Selection = " groundColor [	.725 .529 .412, .725 .529 .412, .392 .471 .647, .137 .137 .216 ]" + vbCrLf
doc.Selection = " skyAngle [ 1.52, 1.56, 1.57 ]" + vbCrLf
doc.Selection = " skyColor [ .275 .353 .608, .529 .627 .784, .451 .529 .725, .451 .529 .725 ]" + vbCrLf
doc.Selection = "}" + vbCrLf
doc.Saved = False
End Sub
BindCommand "BGsky", "Background Sky", "Special Nodes|Backgrounds|Sky"
Sub BGsky
Set doc = Window.Documents.Active
doc.Selection = "Background {" + vbCrLf
doc.Selection = " skyColor [ .235 .478 1, .255 .765 1, .522 .894 1 ]" + vbCrLf
doc.Selection = " skyAngle [ 1.22, 1.48 ]" + vbCrLf
doc.Selection = " groundColor [ .7 .4 .3 ]" + vbCrLf
doc.Selection = "}" + vbCrLf
doc.Saved = False
End Sub
BindCommand "BGSpr", "Background Spring", "Special Nodes|Backgrounds|Spring"
Sub BGSpr
Set doc = Window.Documents.Active
doc.Selection = "Background {" + vbCrLf
doc.Selection = "	skyAngle [ 1, 1.5, 1.571 ]" + vbCrLf
doc.Selection = "	skyColor [ 0 .2 .7, 0 .5 1.0, .85 .9 .95 ]" + vbCrLf
doc.Selection = "	groundAngle	[ 1.4, 1.52, 1.57 ]" + vbCrLf
doc.Selection = "	groundColor [ .25 .455 .141, .25 .455 .141, .1 .329 .129, .259 .408 .4 ]" + vbCrLf
doc.Selection = "}" + vbCrLf
doc.Saved = False
End Sub
BindCommand "BGsun", "Background Sunset", "Special Nodes|Backgrounds|Sunset"
Sub BGsun
Set doc = Window.Documents.Active
doc.Selection = "Background {" + vbCrLf
doc.Selection = "	skyAngle [ 1.1, 1.4, 1.57 ]" + vbCrLf
doc.Selection = "	skyColor [ .333 .118 .118, .333 .118 .118, .706 .392 .235, .941 .863 .392 ]" + vbCrLf
doc.Selection = "	groundAngle	[ 1.4, 1.57 ]" + vbCrLf
doc.Selection = "	groundColor [ .863 .549 .235, .863 .549 .235, .627 .275 .157 ]" + vbCrLf
doc.Selection = "}" + vbCrLf
doc.Saved = False
End Sub
BindCommand "BGund", "Background Underwater", "Special Nodes|Backgrounds|Underwater"
Sub BGund
Set doc = Window.Documents.Active
doc.Selection = "Background {" + vbCrLf
doc.Selection = "	groundColor [ .15 .3 .35, .35 .65 .65 ]" + vbCrLf
doc.Selection = "	groundAngle [ 1.5708 ]" + vbCrLf
doc.Selection = "	skyColor [ 1 1 1, .35 .65 .65 ]" + vbCrLf
doc.Selection = "	skyAngle [ 1.5708 ]" + vbCrLf
doc.Selection = "}" + vbCrLf
doc.Saved = False
End Sub
BindCommand "BGvs", "Background VRMLsuck gray", "Special Nodes|Backgrounds|VRMLsuck Gray"
Sub BGvs
Set doc = Window.Documents.Active
doc.Selection = "Background {" + vbCrLf
doc.Selection = " groundColor [ .580392 .580392 .588235 ]" + vbCrLf
doc.Selection = " skyColor [ .580392 .580392 .588235 ]" + vbCrLf
doc.Selection = "}" + vbCrLf
doc.Saved = False
End Sub
BindCommand "BGwgry", "Background Warm Gray", "Special Nodes|Backgrounds|Warm Gray"
Sub BGwgry
Set doc = Window.Documents.Active
doc.Selection = "Background {" + vbCrLf
doc.Selection = "	skyColor [ .827 .792 .796 ]" + vbCrLf
doc.Selection = "	groundColor [ .945 .91 .914, .945 .91 .914, .859 .824 .827, .827 .792 .796 ]" + vbCrLf
doc.Selection = "	groundAngle [ 1.2, 1.5, 1.54 ]" + vbCrLf
doc.Selection = "}" + vbCrLf
doc.Saved = False
End Sub
BindCommand "BGwhi", "Background White", "Special Nodes|Backgrounds|White"
Sub BGwhi
Set doc = Window.Documents.Active
doc.Selection = "Background {" + vbCrLf
doc.Selection = " groundColor [ 1 1 1 ]" + vbCrLf
doc.Selection = " skyColor [ 1 1 1 ]" + vbCrLf
doc.Selection = "}" + vbCrLf
doc.Saved = False
End Sub
BindCommand "BGwhd", "Background White_Dune", "Special Nodes|Backgrounds|White_Dune"
Sub BGwhd
Set doc = Window.Documents.Active
doc.Selection = "Background {" + vbCrLf
doc.Selection = " skyColor [ .525 .765 .878, .525 .765 .878, .894 .992 .98 ]" + vbCrLf
doc.Selection = " skyAngle [ 1.22, 1.48 ]" + vbCrLf
doc.Selection = "groundColor [ .894 .992 .98 ]" + vbCrLf
doc.Selection = "}" + vbCrLf
doc.Saved = False
End Sub
BindCommand "BGwint", "Background Winter", "Special Nodes|Backgrounds|Winter"
Sub BGwint
Set doc = Window.Documents.Active
doc.Selection = "Background {" + vbCrLf
doc.Selection = "	groundAngle	[ 1.57079 ]" + vbCrLf
doc.Selection = "	groundColor	[ 1 1 1, 1 1 1 ]" + vbCrLf
doc.Selection = "	skyAngle	[ 1.3, 1.57 ]" + vbCrLf
doc.Selection = "	skyColor	[ .3 .45 .7, .6 .7 .85, .85 .9 .95 ]" + vbCrLf
doc.Selection = "}" + vbCrLf
doc.Saved = False
End Sub